import React, { useCallback } from "react";
import { UI } from '@hyext/hy-ui'
import "./index.hycss";
import StatusButton from "../../components/StatusButton";
import { API_QA_STATUS_TEXT, API_QA_STATUS_ICON_COLOR, API_QA_STATUS_ICON } from "../../constants";

const {
  View,
  Text,
  ScrollView,
  NavigationBar,
} = UI

function Tests (props) {
  const apiInfo = props.location.state
  const tests = apiInfo.tests

  const handlePress = useCallback((testInfo) => {
    props.history.push('/detail', testInfo)
  }, [props.history])

  return (
    <>
    <NavigationBar
       title={'测试总汇'}
       onPressBack={() => {
        props.history.goBack()
      }}
      ></NavigationBar>
    <ScrollView contentContainerStyle={{ padding: 15 }}>
    <View className="">
        <View className="title"><Text className="title-text" numberOfLines={1}>API信息</Text></View>
        <View className="apiInfo-main">
        <Text numberOfLines={1}>调用路径: {apiInfo.path}</Text>
        <Text numberOfLines={1}>方法名: {apiInfo.name}</Text>
        <Text numberOfLines={1}>状态: {API_QA_STATUS_TEXT[apiInfo.status]}</Text>
      </View>
      </View>
      <View className="">
        <View className="title"><Text className="title-text" numberOfLines={1}>测试用例列表</Text></View>
        {
          tests.length 
            ? <TestCaseList onPress={handlePress} list={tests}></TestCaseList>
            : <Text numberOfLines={1}>测试用例还没有运行~</Text>
        }
      </View>
    </ScrollView>
    </>
  )
}

function formatTitle(title) {
  const temp = title.split('-')[1]
  return temp !== undefined ? temp.trim() : '未知测试用例标题'
}

function  TestCaseList(props) {

  return (
    <View className="testcase-list">
      {
        props.list.map((item, i) => {
          return (
            <StatusButton
              iconType={API_QA_STATUS_ICON[item.status]}
              iconColor={API_QA_STATUS_ICON_COLOR[item.status]}
              text={formatTitle(item.title)}
              onPress={() => {
                props.onPress(item)
              }}
              key={i}
            ></StatusButton>
          )
        }) 
      }
    </View>
  )
}

export default Tests